@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 
 use Moose 0.99;
 use namespace::autoclean 0.09;
@@ -151,6 +151,9 @@ sub configure {
             }
         ],
 
+        # automatically extract Perl::Critic policy prereqs
+        'AutoPrereqs::Perl::Critic',
+
         # Add the $AUTHORITY variable and metadata to your distribution
         [
             'Authority',
